Learn R Programming

isni (version 0.1)

fun.gfit: Internal Function to fit the missing data model and obtain the predicted probabilities of being observed for all observations.

Description

Fit missing data model and obtain predicted probabilities of being observed for all observations.

Usage

fun.gfit(data, gmodel)

Arguments

data

the name of the dataset for fitting missing data mechansim model

gmodel

a formula to specify a multinomial transitional missing data model.